@@ -22,6 +22,7 @@
  * USA
  */
 
+#include "config.h"
 #include "element.h"
 #include "atom.h"
 #include "bond.h"
@@ -240,7 +241,7 @@ bool Atom::SetProperty (unsigned property, char const *value)
 		break;
 	}
 	case GCU_PROP_ID: {
-		char *Id = g_strdup_printf ("a%s", value);
+		char *Id = (*value == 'a')? g_strdup (value): g_strdup_printf ("a%s", value);
 		SetId (Id);
 		break;
 	}
@@ -267,9 +268,10 @@ string Atom::GetProperty (unsigned property) const
 			res << m_x / doc->GetScale () << " " << m_y / doc->GetScale ();
 		else
 			res << m_x << " " << m_y;
+		break;
 	}
 	default:
-		break;
+			return Object::GetProperty (property);
 	}
 	return res.str ();
 }
