@@ -4,7 +4,7 @@
  * Gnome Crystal
  * window.cc 
  *
- * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,10 +25,12 @@
 #include "config.h"
 #include "window.h"
 #include "application.h"
+#include "docprop.h"
 #include "document.h"
 #include "prefs.h"
 #include "view-settings.h"
 #include <gcu/crystalview.h>
+#include <gcu/print-setup-dlg.h>
 #include <glib/gi18n.h>
 #include <cstring>
 
@@ -62,14 +64,29 @@ static void on_file_save_as (GtkWidget *widget, gcWindow* Win)
 	Win->GetApplication ()->OnFileSaveAs ();
 }
 
+static void on_properties(GtkWidget* widget, gcWindow* Win)
+{
+	new gcDocPropDlg (Win->GetDoc ());
+}
+
 static void on_file_close (GtkWidget *widget, gcWindow* Win)
 {
 	Win->GetApplication ()->OnFileClose ();
 }
 
+static void on_page_setup (GtkWidget *widget, gcWindow* Win)
+{
+	new PrintSetupDlg (Win->GetApplication (), Win->GetView ());
+}
+
+static void on_print_preview (GtkWidget *widget, gcWindow* Win)
+{
+	Win->GetView ()->Print (true);
+}
+
 static void on_file_print (GtkWidget *widget, gcWindow* Win)
 {
-	Win->GetApplication ()->OnFilePrint ();
+	Win->GetView ()->Print (false);
 }
 
 static void on_file_save_as_image(GtkWidget* widget, gcWindow* Win)
@@ -100,7 +117,12 @@ static void on_prefs (GtkWidget* widget, gcWindow* Win)
 	new gcPrefsDlg (Win->GetApp ());
 }
 
-static void on_about (GtkWidget *widget, void *data)
+static void on_about_activate_url (GtkAboutDialog *about, const gchar *url, gpointer data)
+{
+	reinterpret_cast <gcWindow *> (data)->GetApp ()->OnWeb (url);
+}
+
+static void on_about (GtkWidget *widget, gcWindow* Win)
 {
 	char const *authors[] = {"Jean Bréfort", NULL};
 //	char * documentors[] = {NULL};
@@ -117,6 +139,8 @@ static void on_about (GtkWidget *widget, void *data)
 		"along with this program; if not, write to the Free Software\n"
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1307\n"
 		"USA";
+
+	gtk_about_dialog_set_url_hook (on_about_activate_url, Win, NULL);
 /* Note to translators: replace the following string with the appropriate credits for you lang */
 	char const *translator_credits = _("translator_credits");
 	GdkPixbuf *logo = gdk_pixbuf_new_from_file (PIXMAPSDIR"/gcrystal_logo.png", NULL);
@@ -125,7 +149,7 @@ static void on_about (GtkWidget *widget, void *data)
 					"authors", authors,
 					"artists", artists,
 					"comments", _("Gnome Crystal is a lightweight crystal structures viewer for Gnome"),
-					"copyright", _("Copyright © 1999-2007 by Jean Bréfort"),
+					"copyright", _("Copyright © 1999-2008 by Jean Bréfort"),
 					"license", license,
 					"logo", logo,
 					"translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? 
@@ -187,6 +211,11 @@ static void on_mail (GtkWidget *widget, gcWindow* Win)
 	Win->GetApp ()->OnMail ();
 }
 
+static void on_live_assistance (GtkWidget *widget, gcWindow *Win)
+{
+	Win->GetApplication ()->OnLiveAssistance ();
+}
+
 static void on_bug (GtkWidget *widget, gcWindow* Win)
 {
 	Win->GetApplication ()->OnBug ();
@@ -259,8 +288,14 @@ static GtkActionEntry entries[] = {
 		  N_("Save the current file with a different name"), G_CALLBACK (on_file_save_as) },
 	  { "SaveAsImage", GTK_STOCK_SAVE_AS, N_("Save As _Image..."), "<control>I",
 		  N_("Save the current file as an image"), G_CALLBACK (on_file_save_as_image) },
+	  { "PageSetup", NULL, N_("Page Set_up..."), NULL,
+		  N_("Setup the page settings for your current printer"), G_CALLBACK (on_page_setup) },
+	  { "PrintPreview", GTK_STOCK_PRINT_PREVIEW, N_("Print Pre_view"), NULL,
+		  N_("Print preview"), G_CALLBACK (on_print_preview) },
 	  { "Print", GTK_STOCK_PRINT, N_("_Print..."), "<control>P",
 		  N_("Print the current file"), G_CALLBACK (on_file_print) },
+	  { "Properties", GTK_STOCK_PROPERTIES, N_("Prope_rties..."), NULL,
+		  N_("Modify the file's properties"), G_CALLBACK (on_properties) },
 	  { "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
 		  N_("Close the current file"), G_CALLBACK (on_file_close) },
 	  { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
@@ -292,6 +327,8 @@ static GtkActionEntry entries[] = {
 		  N_("View help for Gnome Crystal"), G_CALLBACK (on_help) },
 	  { "Web", NULL, N_("Gnome Chemistry Utils on the _web"), NULL,
 		  N_("Browse the Gnome Chemistry Utils's web site"), G_CALLBACK (on_web) },
+	  { "LiveAssistance", NULL, N_("Live assistance"), NULL,
+		  N_("Open the Gnome Chemistry Utils IRC channel"), G_CALLBACK (on_live_assistance) },
 	  { "Mail", NULL, N_("_Ask a question"), NULL,
 		  N_("Ask a question about the Gnome Chemistry Utils"), G_CALLBACK (on_mail) },
 	  { "Bug", NULL, N_("Report _Bugs"), NULL,
@@ -309,9 +346,13 @@ static const char *ui_description =
 "      <menuitem action='Save'/>"
 "      <menuitem action='SaveAs'/>"
 "      <menuitem action='SaveAsImage'/>"
-"      <separator name='file-sep1'/>"
+"	   <separator name='file-sep1'/>"
+"      <menuitem action='PageSetup'/>"
+"      <menuitem action='PrintPreview'/>"
 "      <menuitem action='Print'/>"
 "      <separator name='file-sep2'/>"
+"      <menuitem action='Properties'/>"
+"      <separator name='file-sep3'/>"
 "      <menuitem action='Close'/>"
 "      <menuitem action='Quit'/>"
 "    </menu>"
@@ -334,9 +375,10 @@ static const char *ui_description =
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Help'/>"
-"      <placeholder name='mail'/>"
-"      <placeholder name='web'/>"
-"      <placeholder name='bug'/>"
+"      <menuitem action='Mail'/>"
+"      <menuitem action='Web'/>"
+"      <menuitem action='LiveAssistance'/>"
+"      <menuitem action='Bug'/>"
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
@@ -348,31 +390,6 @@ static const char *ui_description =
 "  </toolbar>"
 "</ui>";
 
-static const char *ui_mail_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='mail'>"
-"        <menuitem action='Mail'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
-static const char *ui_web_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='web'>"
-"        <menuitem action='Web'/>"
-"      </placeholder>"
-"      <placeholder name='bug'>"
-"        <menuitem action='Bug'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
 gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 {
 	GtkWidget *vbox;
@@ -411,17 +428,10 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 		g_error_free (error);
 		exit (EXIT_FAILURE);
 	}
-	if (App->HasWebBrowser () && !gtk_ui_manager_add_ui_from_string (m_UIManager, ui_web_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
-	if (App->HasMailAgent () && !gtk_ui_manager_add_ui_from_string (m_UIManager, ui_mail_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
 
 	GtkWidget *menu = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/FileMenu/Open");
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
+	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
 	gtk_recent_filter_add_mime_type (filter, "application/x-gcrystal");
 	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (w), filter);
