@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-app.cc 
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,6 +24,8 @@
 
 #include "config.h"
 #include "gchemtable-app.h"
+#include "gchemtable-curve.h"
+#include "gchemtable-data.h"
 #include "gchemtable-elt.h"
 #include <gcu/chemistry.h>
 #include <gcu/element.h>
@@ -34,16 +36,21 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtkuimanager.h>
 #include <gtk/gtkwindow.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <cstdlib>
 #include <cstring>
 
-static void on_quit (GtkWidget *widget, void *data)
+static void on_quit (GtkWidget *widget, GChemTableApp *App)
 {
+	delete App;
 	gtk_main_quit();
 }
 
-void on_no_colors (GtkWidget *widget, GChemTableApp *App)
+static void on_new_chart (GtkWidget *widget, GChemTableApp *App)
+{
+	App->OnNewChart ();
+}
+
+static void on_no_colors (GtkWidget *widget, GChemTableApp *App)
 {
 	App->SetColorScheme ("none");
 }
@@ -53,12 +60,12 @@ void on_default_colors (GtkWidget *widget, GChemTableApp *App)
 	App->SetColorScheme ("default");
 }
 
-void on_state_colors (GtkWidget *widget, GChemTableApp *App)
+static void on_state_colors (GtkWidget *widget, GChemTableApp *App)
 {
 	App->SetColorScheme ("state");
 }
 
-void on_family_colors (GtkWidget *widget, GChemTableApp *App)
+static void on_family_colors (GtkWidget *widget, GChemTableApp *App)
 {
 	App->SetColorScheme ("family");
 }
@@ -73,22 +80,19 @@ void on_electroneg_colors (GtkWidget *widget, GChemTableApp *App)
 	App->SetColorScheme ("electroneg");
 }
 
-void on_radius_colors (GtkWidget *widget, GChemTableApp *App)
+static void on_radius_colors (GtkWidget *widget, GChemTableApp *App)
 {
 	App->SetColorScheme ("radius");
 }
 
-void on_block_colors (GtkWidget *widget, GChemTableApp *App)
+static void on_block_colors (GtkWidget *widget, GChemTableApp *App)
 {
 	App->SetColorScheme ("block");
 }
 
 static void on_about_activate_url (GtkAboutDialog *about, const gchar *url, gpointer data)
 {
-	GnomeVFSResult error = gnome_vfs_url_show(url);
-	if (error != GNOME_VFS_OK) {
-		g_print("GnomeVFSResult while trying to launch URL in about dialog: error %u\n", error);
-	}
+	reinterpret_cast <Application *> (data)->OnWeb (url);
 }
 
 static void on_help (GtkWidget *widget, GChemTableApp *app)
@@ -106,6 +110,11 @@ static void on_mail (GtkWidget *widget, GChemTableApp *app)
 	app->OnMail ();
 }
 
+static void on_live_assistance (GtkWidget *widget, GChemTableApp *app)
+{
+	app->OnLiveAssistance ();
+}
+
 static void on_bug (GtkWidget *widget, GChemTableApp *app)
 {
 	app->OnBug ();
@@ -116,13 +125,15 @@ static void on_about (GtkWidget *widget, GChemTableApp *app)
 	app->OnAbout ();
 }
 
-void on_changed (GtkPeriodic* periodic, guint Z, GChemTableApp *app)
+static void on_changed (GtkPeriodic* periodic, guint Z, GChemTableApp *app)
 {
 	app->OnElement (Z);
 }
 
 static GtkActionEntry entries[] = {
   { "FileMenu", NULL, N_("_File") },
+	  { "NewChart", NULL, N_("New _Chart"), "<control>N",
+		  N_("Create a new chart"), G_CALLBACK (on_new_chart) },
 	  { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
 		  N_("Quit GChemTable"), G_CALLBACK (on_quit) },
   { "ViewMenu", NULL, N_("_View") },
@@ -154,6 +165,8 @@ static GtkActionEntry entries[] = {
 		  N_("View help for the Periodic Table"), G_CALLBACK (on_help) },
 	  { "Web", NULL, N_("Gnome Chemistry Utils on the _web"), NULL,
 		  N_("Browse the Gnome Chemistry Utils's web site"), G_CALLBACK (on_web) },
+	  { "LiveAssistance", NULL, N_("Live assistance"), NULL,
+		  N_("Open the Gnome Chemistry Utils IRC channel"), G_CALLBACK (on_live_assistance) },
 	  { "Mail", NULL, N_("_Ask a question"), NULL,
 		  N_("Ask a question about the Gnome Chemistry Utils"), G_CALLBACK (on_mail) },
 	  { "Bug", NULL, N_("Report _Bugs"), NULL,
@@ -166,6 +179,9 @@ static const char *ui_description =
 "<ui>"
 "  <menubar name='MainMenu'>"
 "    <menu action='FileMenu'>"
+"	   <separator name='file-sep1'/>"
+"      <menuitem action='NewChart'/>"
+"	   <separator name='file-sep2'/>"
 "      <menuitem action='Quit'/>"
 "    </menu>"
 "    <menu action='ViewMenu'>"
@@ -182,50 +198,26 @@ static const char *ui_description =
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Help'/>"
-"      <placeholder name='mail'/>"
-"      <placeholder name='web'/>"
-"      <placeholder name='bug'/>"
+"      <menuitem action='Mail'/>"
+"      <menuitem action='Web'/>"
+"      <menuitem action='LiveAssistance'/>"
+"      <menuitem action='Bug'/>"
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
 "</ui>";
 
-static const char *ui_mail_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='mail'>"
-"        <menuitem action='Mail'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
-static const char *ui_web_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='web'>"
-"        <menuitem action='Web'/>"
-"      </placeholder>"
-"      <placeholder name='bug'>"
-"        <menuitem action='Bug'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
 static void get_state_color (int Z, GdkColor *color, GChemTableApp *App)
 {
 	App->GetStateColor (Z, color);
 }
 
-void on_changed_temp (GtkRange *range, GChemTableApp *app)
+static void on_changed_temp (GtkRange *range, GChemTableApp *app)
 {
 	app->SetTemperature (gtk_range_get_value (range));
 }
 
-void on_changed_family (GtkComboBox *box,  GChemTableApp *app)
+static void on_changed_family (GtkComboBox *box,  GChemTableApp *app)
 {
 	app->SetFamily (gtk_combo_box_get_active (box));
 }
@@ -255,16 +247,21 @@ static void get_block_color (int Z, GdkColor *color, GChemTableApp *App)
 	App->GetBlockColor (Z, color);
 }
 
-// FIXME "the following line should be edited for stable releases"
-GChemTableApp::GChemTableApp (): Application ("gchemtable-unstable")
+static void on_destroy (GChemTableApp *App)
+{
+	delete App;
+	gtk_main_quit ();
+}
+
+GChemTableApp::GChemTableApp (): Application ("gchemtable")
 {
 	GtkVBox* vbox;
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW(window), _("Periodic table of the elements"));
-	g_signal_connect (G_OBJECT (window), "destroy",
-		 G_CALLBACK (gtk_main_quit),
-		 NULL);
+	g_signal_connect_swapped (G_OBJECT (window), "delete-event",
+		 G_CALLBACK (on_destroy),
+		 this);
 
 	g_object_set (G_OBJECT(window), "allow-shrink", FALSE, NULL);
 	
@@ -283,14 +280,6 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable-unstable")
 		g_error_free (error);
 		exit (EXIT_FAILURE);
 	}
-	if (HasWebBrowser () && !gtk_ui_manager_add_ui_from_string (ui_manager, ui_web_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
-	if (HasMailAgent () && !gtk_ui_manager_add_ui_from_string (ui_manager, ui_mail_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
 	periodic = GTK_PERIODIC (gtk_periodic_new());
@@ -339,10 +328,13 @@ GChemTableApp::GChemTableApp (): Application ("gchemtable-unstable")
 	GtkWidget *blocklegend = glade_xml_get_widget (blockxml, "block-legend");
 	colorschemes["block"] = gtk_periodic_add_color_scheme (periodic, (GtkPeriodicColorFunc) get_block_color, blocklegend, this);
 	gtk_widget_show_all (blocklegend);
+	gct_data_init ();
+
 }
 
 GChemTableApp::~GChemTableApp ()
 {
+	gct_data_clear ();
 }
 
 void GChemTableApp::OnAbout ()
@@ -350,7 +342,7 @@ void GChemTableApp::OnAbout ()
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChemTable is a chemical periodic table of the elements application");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2005-2007 Jean Bréfort");
+	const gchar * copyright = _("Copyright © 2005-2008 Jean Bréfort");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -365,7 +357,7 @@ void GChemTableApp::OnAbout ()
 		"Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307\n"
 		"USA";
 	
-	gtk_about_dialog_set_url_hook(on_about_activate_url, NULL, NULL);
+	gtk_about_dialog_set_url_hook (on_about_activate_url, this, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
@@ -647,3 +639,8 @@ void GChemTableApp::GetBlockColor (int Z, GdkColor *color)
 		return;
 	}
 }
+
+void GChemTableApp::OnNewChart ()
+{
+	new GChemTableCurve (this, NULL);
+}
